import os
import nose2
import nose2
import unittest
import shutil
import yaml
from fundamentals.utKit import utKit
import time
from fundamentals import tools

su = tools(
    arguments={"settingsFile": None},
    docString=__doc__,
    logLevel="DEBUG",
    options_first=False,
    projectName="fundamentals"
)
arguments, settings, log, dbConn = su.setup()

# load settings
stream = file(
    "/Users/Dave/.config/fundamentals/fundamentals.yaml", 'r')
settings = yaml.load(stream)
stream.close()

# SETUP AND TEARDOWN FIXTURE FUNCTIONS FOR THE ENTIRE MODULE
moduleDirectory = os.path.dirname(__file__)
utKit = utKit(moduleDirectory)
log, dbConn, pathToInputDir, pathToOutputDir = utKit.setupModule()
utKit.tearDownModule()

dictList = []

for i in range(10000000):

    dictList.append({
        "col1": i,
        "col2": i + 10.,
        "col3": i / 2.,
        "col4": i * 34.
    })

dbSettings = dbSettings = {
    'host': '127.0.0.1',
    'user': 'unittesting',
    'tunnel': False,
    'password': 'utpass',
    'db': 'dryx_unit_testing'
}


class test_insert_list_of_dictionaries_into_database_tables(unittest.TestCase):

    def test_insert_list_of_dictionaries_into_database_tables_function(self):

        t1 = time.time()

        from fundamentals.mysql import insert_list_of_dictionaries_into_database_tables
        insert_list_of_dictionaries_into_database_tables(
            dbConn=dbConn,
            log=log,
            dictList=dictList,
            dbTableName="test_insert_many",
            uniqueKeyList=["col1", "col3"],
            dateModified=True,
            batchSize=1000000,
            replace=True,
            dbSettings=dbSettings
        )

        print time.time() - t1

        # x-print-testpage-for-pessto-marshall-web-object

    # x-class-to-test-named-worker-function



#!/usr/local/bin/python
# encoding: utf-8
"""
*Retrieve an HTML document or file from the web at a given URL*

:Author:
    David Young

:Date Created:
    March 16, 2016
"""
################# GLOBAL IMPORTS ####################
import sys
import os
os.environ['TERM'] = 'vt100'
from fundamentals import tools


def _fetch(url,):
    """
    *Retrieve an HTML document or file from the web at a given URL*

    **Key Arguments:**
      - ``url`` -- the URL of the document or file

    **Return:**
      - ``url`` -- the URL of the document or file, or None if an error occured
      - ``body`` -- the text content of the HTML document.
    """
    import logging as log
    import socket
    from eventlet import Timeout
    from eventlet.green import urllib2
    import sys

    # TRY AND DOWNLOAD X TIMES BEFORE QUITING
    tries = 10
    count = 1
    downloaded = False
    while count < tries and downloaded == False:
        try:
            log.debug('downloading ' + url.get_full_url())
            body = urllib2.urlopen(url).read()
            downloaded = True
        except socket.timeout, e:
            print "timeout on URL, trying again"
            count += 1
        except Exception, e:
            if "[Errno 60]" in str(e):
                log.warning('timeout on URL, trying again' % locals())
                count += 1
            if "Error 502" in str(e):
                log.warning('proxy error on URL, trying again' % locals())
                count += 1
            else:
                log.warning(
                    "could not download " + url.get_full_url() + " : " + str(e) + "\n")
                url = None
                body = None
                downloaded = True

    return url, body



"""
*Tools used to perform download of files and HTML pages from the web*
"""

from _fetch import _fetch
from _dump_files_to_local_drive import _dump_files_to_local_drive
from get_now_datetime_filestamp import get_now_datetime_filestamp
from extract_filename_from_url import extract_filename_from_url
from append_now_datestamp_to_filename import append_now_datestamp_to_filename
from multiobject_download import multiobject_download



import os
import nose
import shutil
import unittest
import yaml
from fundamentals.utKit import utKit
from fundamentals.files import tag

from fundamentals import tools

su = tools(
    arguments={"settingsFile": None},
    docString=__doc__,
    logLevel="DEBUG",
    options_first=False,
    projectName="fundamentals"
)
arguments, settings, log, dbConn = su.setup()

# # load settings
# stream = file(
#     "/Users/Dave/.config/fundamentals/fundamentals.yaml", 'r')
# settings = yaml.load(stream)
# stream.close()

# SETUP AND TEARDOWN FIXTURE FUNCTIONS FOR THE ENTIRE MODULE
moduleDirectory = os.path.dirname(__file__)
utKit = utKit(moduleDirectory)
log, dbConn, pathToInputDir, pathToOutputDir = utKit.setupModule()
utKit.tearDownModule()

# load settings
# stream = file(
#     pathToInputDir + "/example_settings.yaml", 'r')
# settings = yaml.load(stream)
# stream.close()

import shutil
try:
    shutil.rmtree(pathToOutputDir)
except:
    pass
# COPY INPUT TO OUTPUT DIR
shutil.copytree(pathToInputDir, pathToOutputDir)

# Recursively create missing directories
if not os.path.exists(pathToOutputDir):
    os.makedirs(pathToOutputDir)

# xt-setup-unit-testing-files-and-folders


class test_tag(unittest.TestCase):

    def test_tag_function(self):

        from fundamentals.files.tag import tag
        tag(
            log=log,
            filepath=pathToOutputDir + "/file_needing_tagged.dat",
            tags="test,tags, fundamentals",
            rating=3,
            wherefrom="http://www.thespacedoctor.co.uk"
        )

    def test_tag_function_exception(self):

        from fundamentals.files import tag
        try:
            this = tag(
                log=log,
                fakeKey="break the code"
            )
            assert False
        except Exception, e:
            assert True
            print str(e)

        # x-print-testpage-for-pessto-marshall-web-object

    # x-class-to-test-named-worker-function
